
VERSION = (0, 3, 2)


def get_version():
    version = '%s.%s' % (VERSION[0], VERSION[1])
    if VERSION[2]:
        version = '%s.%s' % (version, VERSION[2])
    return version


def get_site(request):
    from django.contrib.sites import models as site_models
    return site_models.RequestSite(request)




from django.contrib import admin

from registration import models
from registration import get_site


class RegistrationAdmin(admin.ModelAdmin):
    actions = ('activate_users', 'resend_activation_email')
    list_display = ('user', 'activation_key_expired')
    raw_id_fields = ('user',)
    search_fields = ('user__username', 'user__first_name')

    def activate_users(self, request, queryset):
        for profile in queryset:
            models.RegistrationProfile.objects.activate_user(profile.activation_key)

    def resend_activation_email(self, request, queryset):
        site = get_site(request)
        for profile in queryset:
            if not profile.activation_key_expired():
                profile.send_activation_email(site)

admin.site.register(models.RegistrationProfile, RegistrationAdmin)




from django import forms
from django.conf import settings
from django.contrib.auth import get_user_model
from django.template.loader import render_to_string

from registration.models import RegistrationProfile


class ActivateUserMixin(object):
    """
    Prepares and send the activation email user's receive to complete their account setup.
    """
    activation_subject_template_name = "registration/email/activation_email_subject.txt"
    activation_template_name = "registration/email/activation_email.txt"
    activation_html_template_name = "registration/email/activation_email.html"

    def create_inactive_user(self, site, send_email=True):
        """
        Creates the inactive user and sends activation email. Only call when form is valid.
        """
        self.user = RegistrationProfile.objects.create_inactive_user(
            self.cleaned_data['username'],
            self.cleaned_data['password1'],
            self.cleaned_data['email'],
            site
        )
        if send_email:
            self.send_activation_email(self.user, site)
        return self.user

    def send_activation_email(self, user, current_site):
        mail_kwargs = {}
        subject = self._get_activation_subject(current_site)
        message = self._get_activation_message(current_site, self.activation_template_name)

        if self.activation_html_template_name:
            mail_kwargs['html_message'] = self._get_activation_message(current_site, self.activation_html_template_name)

        user.email_user(subject, message, settings.DEFAULT_FROM_EMAIL, **mail_kwargs)

    def _get_activation_subject(self, site):
        subject = render_to_string(self.activation_subject_template_name, {'site': site})
        return ''.join(subject.splitlines())

    def _get_activation_message(self, site, template_name):
        return render_to_string(template_name, self.get_email_context(site))

    def get_email_context(self, site):
        return {
            'site': site,
            'activation_key': self.user.registrationprofile.activation_key,
            'expiration_days': settings.ACCOUNT_ACTIVATION_DAYS,
        }


class RegistrationForm(ActivateUserMixin, forms.Form):
    username = forms.RegexField(regex=r'^[\w.@+-]+$', max_length=30,
                                error_messages={'invalid': 'Enter a valid username. '
                                                           'This value may contain only letters, numbers '
                                                           'and @/./+/-/_ characters.'})
    email = forms.EmailField(max_length=75)
    password1 = forms.CharField(widget=forms.PasswordInput())
    password2 = forms.CharField(widget=forms.PasswordInput())

    def clean_username(self):
        user_model = get_user_model()
        try:
            username_lookup = "{}__iexact".format(user_model.USERNAME_FIELD)
            user_model.objects.get(**{username_lookup: self.cleaned_data['username']})
        except user_model.DoesNotExist:
            return self.cleaned_data['username']
        raise forms.ValidationError("Username '%(username)s' is not available." % self.cleaned_data)

    def clean(self):
        if 'password1' in self.cleaned_data and 'password2' in self.cleaned_data:
            if self.cleaned_data['password1'] != self.cleaned_data['password2']:
                raise forms.ValidationError("Passwords must match.")

        return self.cleaned_data




from django import http
from django.views.generic import TemplateView
from django.views.generic.edit import FormView
from django.core.urlresolvers import reverse

from registration import forms
from registration import models
from registration import get_site


class Register(FormView):
    template_name = 'registration/register.html'
    form_class = forms.RegistrationForm

    def get_success_url(self):
        if self.success_url:
            return self.success_url
        return reverse("registration_complete")

    def form_valid(self, form):
        form.create_inactive_user(get_site(self.request))
        return super(Register, self).form_valid(form)


class RegistrationComplete(TemplateView):
    template_name = 'registration/registration_complete.html'


class ActivationComplete(TemplateView):
    template_name = 'registration/activation_complete.html'


class Activate(TemplateView):
    template_name = 'registration/activation_failed.html'

    def get(self, request, *args, **kwargs):
        new_user = models.RegistrationProfile.objects.activate_user(kwargs['activation_key'])
        if new_user:
            return http.HttpResponseRedirect(reverse("registration_activation_complete"))
        return super(Activate, self).get(request, *args, **kwargs)




import datetime
import random
from hashlib import sha1

from django.db import models
from django.db import transaction
from django.conf import settings
from django.contrib.auth import get_user_model
from django.utils.timezone import now as utc_now


class RegistrationManager(models.Manager):
    """Provides shortcuts to account creation and activation"""

    @transaction.atomic
    def create_inactive_user(self, username, password, email):
        new_user = self._get_new_inactive_user(username, password, email)
        self._create_profile(new_user)
        return new_user

    def activate_user(self, activation_key):
        """
        returns user object if successful, otherwise returns false
        """
        try:
            profile = self.get(activation_key=activation_key)
        except self.model.DoesNotExist:
            return False
        if not profile.activation_key_expired():
            active_user = self._do_activate_user(profile.user)
            self._do_activate_profile(profile)
            return active_user
        return False

    def delete_expired_users(self):
        """
        Deletes inactive users with expired profiles.
        """
        for profile in self.filter(user__is_active=False).exclude(activation_key=RegistrationProfile.ACTIVATED):
            if profile.activation_key_expired():
                profile.user.delete()

    def _do_activate_user(self, user):
        user.is_active = True
        user.save()
        return user

    def _do_activate_profile(self, profile):
        profile.activation_key = self.model.ACTIVATED
        profile.save()

    def _get_new_inactive_user(self, username, password, email):
        new_user = get_user_model().objects.create_user(username, email, password)
        new_user.is_active = False
        new_user.save()
        return new_user

    def _create_profile(self, user):
        salt = sha1(str(random.random())).hexdigest()[:5]
        activation_key = sha1(salt + user.username).hexdigest()
        return self.create(user=user, activation_key=activation_key)


class RegistrationProfile(models.Model):
    ACTIVATED = u"ALREADY_ACTIVATED"

    user = models.OneToOneField(settings.AUTH_USER_MODEL)
    activation_key = models.CharField(max_length=40)

    objects = RegistrationManager()

    def __unicode__(self):
        return u"Registration information for %s" % self.user

    def activation_key_expired(self):
        expiration_date = datetime.timedelta(days=settings.ACCOUNT_ACTIVATION_DAYS)
        return self.activation_key == self.ACTIVATED or self.user.date_joined + expiration_date <= utc_now()




from django.conf.urls import patterns, url
from django.contrib.auth import views as auth_views

urlpatterns = patterns(
    '',
    url(r'^login/$', auth_views.login, {'template_name': 'registration/login.html'}, name='auth_login'),
    url(r'^logout/$', auth_views.logout, {'template_name': 'registration/logout.html'}, name='auth_logout'),
    url(r'^password/change/$', auth_views.password_change, name='auth_password_change'),
    url(r'^password/change/done/$', auth_views.password_change_done, name='auth_password_change_done'),
    url(r'^password/reset/$', auth_views.password_reset, name='auth_password_reset'),
    url(r'^password/reset/confirm/(?P<uidb64>[0-9A-Za-z]+)-(?P<token>.+)/$', auth_views.password_reset_confirm, name='auth_password_reset_confirm'),
    url(r'^password/reset/complete/$', auth_views.password_reset_complete, name='auth_password_reset_complete'),
    url(r'^password/reset/done/$', auth_views.password_reset_done, name='auth_password_reset_done'),
)




import os
from setuptools import setup

TEST_REQUIREMENTS = [
    'django>=1.8',
]

README = os.path.join(os.path.dirname(__file__), 'README')
setup(
    name="django-registration-gv",
    version="0.3.2",
    author="Aaron Madison",
    description="Django registration app",
    url="https://github.com/madisona/django-registration",
    test_suite='runtests.runtests',
    packages=('registration',),
    include_package_data=True,
    tests_require=TEST_REQUIREMENTS,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
    ],
    zip_safe=False,
)




from django.conf.urls import patterns, url

from registration import views
from registration import auth_urls


registration_urls = patterns(
    '',
    url(r'^register/$', views.Register.as_view(), name='registration_register'),
    url(r'^register/complete/$', views.RegistrationComplete.as_view(), name='registration_complete'),
    url(r'^activate/complete/$', views.ActivationComplete.as_view(), name='registration_activation_complete'),
    url(r'^activate/(?P<activation_key>\w+)/$', views.Activate.as_view(), name='registration_activate'),
)

urlpatterns = registration_urls + auth_urls.urlpatterns
